@@ -11,6 +11,8 @@ class BaseField(object):
     * `db_field` - The name this field will have when sent to MongoDB
     * `default` - The default value (or callable) that will be used when first creating an instance that has no value set for the field
     * `required` - Indicates that if the field value evaluates to empty (using the `is_empty` method) a validation error is raised
+    * `on_save` - A function of the form `lambda doc, creating` that is called right before sending the document to the DB.
+    * `unique` - Indicates whether an unique index should be created for this field.
 
     To create a new field, four methods can be overwritten:
 
@@ -22,7 +24,7 @@ class BaseField(object):
 
     total_creation_counter = 0
 
-    def __init__(self, db_field=None, default=None, required=False, on_save=None):
+    def __init__(self, db_field=None, default=None, required=False, on_save=None, unique=None):
         global creation_counter
         self.creation_counter = BaseField.total_creation_counter
         BaseField.total_creation_counter += 1
@@ -31,6 +33,7 @@ class BaseField(object):
         self.required = required
         self.default = default
         self.on_save = on_save
+        self.unique = unique
 
     def is_empty(self, value):
         return value is None
